@@ -1,34 +1,25 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2005 Olivier Goffart <ogoffart at kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2005 Olivier Goffart <ogoffart at kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KNOTIFYCONFIGWIDGET_H
 #define KNOTIFYCONFIGWIDGET_H
 
-#include <knotifyconfig_export.h>
-#include <QWidget>
 #include <QString>
+#include <QWidget>
+#include <knotifyconfig_export.h>
+
+#include <memory>
 
 class KNotifyConfigElement;
 class KNotifyConfigWidgetPrivate;
 /**
  * @class KNotifyConfigWidget knotifyconfigwidget.h <KNotifyConfigWidget>
  *
- * Configure the notification for a given application / context
+ * Configure the notification for a given application
  *
  * You probably will want to use the static function configure
  *
@@ -41,7 +32,7 @@ class KNOTIFYCONFIG_EXPORT KNotifyConfigWidget : public QWidget
     Q_OBJECT
 public:
     explicit KNotifyConfigWidget(QWidget *parent);
-    ~KNotifyConfigWidget();
+    ~KNotifyConfigWidget() override;
 
     /**
      * Show a dialog with the widget.
@@ -52,15 +43,11 @@ public:
     static KNotifyConfigWidget *configure(QWidget *parent = nullptr, const QString &appname = QString());
 
     /**
-     * Change the application and the context
+     * Change the application
      *
      * @param appname name of the application.   if null QCoreApplication::instance()->applicationName() is used
-     * @param context_name the name of the context, if null , avery context are considered
-     * @param context_value the context value
      */
-    void setApplication(const QString &appname = QString(),
-                        const QString &context_name = QString(),
-                        const QString &context_value = QString());
+    void setApplication(const QString &appname = QString());
 
     /**
      * Select a given notification in the current list
@@ -97,12 +84,12 @@ Q_SIGNALS:
      */
     void changed(bool state);
 
-private:
-    KNotifyConfigWidgetPrivate *const d;
 private Q_SLOTS:
-    void slotEventSelected(KNotifyConfigElement *e);
-    void slotActionChanged();
+    KNOTIFYCONFIG_NO_EXPORT void slotEventSelected(KNotifyConfigElement *e);
+    KNOTIFYCONFIG_NO_EXPORT void slotActionChanged();
 
+private:
+    std::unique_ptr<KNotifyConfigWidgetPrivate> const d;
 };
 
 #endif
